@@ -435,6 +435,7 @@ class SOP(PersistenceSystem):
         location: str = "http://localhost:8083",
         username: Optional[str] = "Administrator",
         password: Optional[str] = None,
+        timeout: Optional[int] = 60
     ):
         if not location.startswith("http"):
             raise ValueError(
@@ -445,6 +446,7 @@ class SOP(PersistenceSystem):
         self.username = username
         self.password = password
         self.client = None
+        self.timeout = timeout
         self.local = True if location.startswith("http://localhost") else False
 
     def write(self, g: Graph, graph_iri, leading_comments=None):
@@ -458,8 +460,6 @@ class SOP(PersistenceSystem):
         if leading_comments:
             content = ''.join(leading_comments)
         content = (bytes(content, encoding="utf-8") + bytes(g.serialize(), encoding="utf-8"))
-#        content += str(g.serialize(format="turtle", encoding="utf-8"))
-#        content = bytes(content,encoding="utf-8")
         headers = {}
         if self.local:
             headers["Cookie"] = "username=Administrator"
@@ -480,6 +480,7 @@ class SOP(PersistenceSystem):
             data=form_data,
             files={"file": io.BytesIO(content)},
             headers=headers,
+            timeout=self.timeout,
         )
         return parse_qs(response.text)["message"][0]
 
